#
# spec file for package ksystemstats5
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2021 Fabian Vogt <fabian@ritter-vogt.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without released
Name:           ksystemstats5
Version:        5.27.11
Release:        bp156.1.2
# Full Plasma 5 version (e.g. 5.8.95)
%{!?_plasma5_bugfix: %define _plasma5_bugfix %{version}}
# Latest ABI-stable Plasma (e.g. 5.8 in KF5, but 5.8.95 in KUF)
%{!?_plasma5_version: %define _plasma5_version %(echo %{_plasma5_bugfix} | awk -F. '{print $1"."$2}')}
Summary:        Plugin based system monitoring daemon
# Actually (GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL) AND CC0-1.0 AND BSD-3-Clause AND BSD-2-Clause
License:        BSD-2-Clause AND BSD-3-Clause AND CC0-1.0 AND GPL-2.0-or-later
Group:          System/GUI/KDE
URL:            http://www.kde.org
Source:         https://download.kde.org/stable/plasma/%{version}/ksystemstats-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/plasma/%{version}/ksystemstats-%{version}.tar.xz.sig
Source2:        plasma.keyring
%endif
BuildRequires:  cmake >= 3.16
BuildRequires:  extra-cmake-modules >= 5.98.0
# TODO: This is now a hard requirement
#%%ifnarch s390 s390x
BuildRequires:  libsensors4-devel
#%%endif
%if 0%{?suse_version} < 1550
BuildRequires:  gcc13-PIE
BuildRequires:  gcc13-c++
%endif
BuildRequires:  systemd-rpm-macros
BuildRequires:  (cmake(KSysGuard) >= %{_plasma5_version} with cmake(KSysGuard) < 6)
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5DBusAddons)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5NetworkManagerQt)
BuildRequires:  cmake(KF5Solid)
BuildRequires:  cmake(Qt5Core) >= 5.15
BuildRequires:  cmake(Qt5Test)
BuildRequires:  pkgconfig(libnl-3.0)
BuildRequires:  pkgconfig(libudev)
# For %%check
%if 0%{?suse_version} > 1599
BuildRequires:  /usr/bin/dbus-run-session
%else
BuildRequires:  dbus-1
%endif
Conflicts:      ksysguard5 < 5.21.80
%{systemd_ordering}

%description
KSystemStats is a daemon that collects statistics about the running system.

%lang_package

%prep
%autosetup -p1 -n ksystemstats-%{version}

%build
%if 0%{?suse_version} < 1550
  export CXX=g++-13
%endif
%cmake_kf5 -d build -- -DBUILD_TESTING=ON
%cmake_build

%install
%kf5_makeinstall -C build

%find_lang ksystemstats_plugins %{name}.lang

%check
export CTEST_OUTPUT_ON_FAILURE=1
dbus-run-session make %{?_smp_mflags} -C build VERBOSE=1 test

%preun
%{systemd_user_preun plasma-ksystemstats.service}

%post
%{systemd_user_post plasma-ksystemstats.service}

%postun
%{systemd_user_postun plasma-ksystemstats.service}

%files
%license LICENSES/*
%{_kf5_bindir}/ksystemstats
%{_kf5_bindir}/kstatsviewer
%dir %{_kf5_plugindir}/ksystemstats/
%{_kf5_plugindir}/ksystemstats/ksystemstats_plugin_{cpu,disk,gpu,lmsensors,memory,network,osinfo,power}.so
%{_kf5_sharedir}/dbus-1/services/org.kde.ksystemstats.service
%{_userunitdir}/plasma-ksystemstats.service

%files lang -f %{name}.lang

%changelog
* Wed Mar  6 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.11:
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.11
- No code changes since 5.27.10
* Wed Feb 28 2024 Christophe Marin <christophe@krop.fr>
- Make sure ksystemstats5 builds using ksysguard from Plasma 5
* Wed Jan 31 2024 Christophe Marin <christophe@krop.fr>
- Switch to the latest GCC version available in Leap for packages
  that can't build with the default compiler
* Wed Dec  6 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.10
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.10
- No code changes since 5.27.9
* Tue Oct 24 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.9
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.9
- No code changes since 5.27.8
* Wed Oct 11 2023 Simon Lees <sflees@suse.de>
- dbus-1 no longer provides dbus-run-session, so BuildRequire
  it explicitly
* Tue Sep 12 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.8
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.8
- Changes since 5.27.7:
  * NvidiaSmiProcess: Fix missing data for GPU 2+ BUG: 473424 (kde#473424)
* Tue Aug  1 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.7
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.7
- Changes since 5.27.6:
  * gpu/nvidia: Discover data fields based on headers (kde#470474)
* Tue Jun 20 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.6
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.6
- No code changes since 5.27.5
* Tue May  9 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.5
- No code changes since 5.27.4
* Tue Apr  4 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.4
- No code changes since 5.27.3
* Tue Mar 14 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.3
- No code changes since 5.27.2
* Tue Feb 28 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.2
- No code changes since 5.27.1
* Tue Feb 21 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.1
- Changes since 5.27.0:
  * gpu/nvidia: lower pci id (kde#462512)
* Thu Feb  9 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.0
- No code changes since 5.26.90
* Thu Jan 19 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.90
- Changes since 5.26.5:
  * cpu: Account for offline processors when adding CPU objects (kde#459130)
  * plugins/gpu: Use pci address to identify nvidia gpus (kde#463033,kde#461361)
  * plugins/gpu: Don't let a newline confuse the nvidia-smi output parsing (kde#462512)
  * Use ecm_set_disabled_deprecation_versions
  * fix null pointer in amd platforms
  * initial implementation for NVidia GPUs
  * Install po folder
  * Remove unused includes
* Wed Jan  4 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.5
- No code changes since 5.26.4
* Tue Nov 29 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.4
- No code changes since 5.26.3
* Tue Nov  8 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.3
- No code changes since 5.26.2
* Wed Oct 26 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.2
- No code changes since 5.26.1
* Tue Oct 18 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.1
- No code changes since 5.26.0
* Thu Oct  6 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.0
- Changes since 5.25.90:
  * Install po folder
* Thu Sep 15 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.90
- Changes since 5.25.5:
  * New CPU cumulative sensors
  * Add FreeBSD Qt6 CI support
  * Remove unused include
  * Request passing unit tests on Linux and BSD
  * GPU: Query for DRM devices and use DRM number as card number (kde#453283)
  * Add REUSE CI check
* Tue Sep  6 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.5
- No code changes since 5.25.4
* Tue Aug  2 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.4
- No code changes since 5.25.3
* Tue Jul 12 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.3
- No code changes since 5.25.2
* Tue Jun 28 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.2
- No code changes since 5.25.1
* Tue Jun 21 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.1
- No code changes since 5.25.0
* Thu Jun  9 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.0
- No code changes since 5.24.90
* Thu May 19 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.90
- Changes since 5.24.5:
  * Add more network sensor
  * Add a window system sensor (kde#452461)
  * cmake: Make sure we also search for dbus interfaces in DESTDIR
  * Remove duplicate header between header cpp file
  * Add Qt6 CI
  * Allow to compile against qt6
  * CPU Plugin: Prevent integer overflow of total usage (kde#448626)
  * Set proper initial values for many SensorProperties (kde#446414)
  * disks: Properly initialize read/write counters (kde#448494)
* Tue May  3 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.5
- No code changes since 5.24.4
* Tue Mar 29 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.4
- No code changes since 5.24.3
* Tue Mar  8 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.3
- No code changes since 5.24.2
* Tue Feb 22 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.2
- No code changes since 5.24.1
* Tue Feb 15 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.1
- Changes since 5.24.0:
  * CPU Plugin: Prevent integer overflow of total usage (kde#448626)
* Sat Feb  5 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.0
- Changes since 5.23.90:
  * CPU Plugin: Prevent integer overflow of total usage (kde#448626)
  * disks: Properly initialize read/write counters (kde#448494)
* Thu Jan 13 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.90
- Changes since 5.23.5:
  * Add support for bits per second (kde#418968)
  * Fix some clazy warnings
  * Don't update disks if no one is listening (kde#445039)
  * Add GitLab CI
  * Update lmsensors.cpp to compile with clang+libcxx
  * Update loadaverages.cpp to compile with clang+libcxx
  * Update freebsdbackend.cpp: fix typo in sysctl
  * Add description for the Sensors package
  * Move find_package line
  * Fix missing "Hardware Sensors" on Linux (kde#442528)
  * Fix .kde-ci file
  * Read extra amd gpu sensors
  * Correct discoverSensors chip detection (kde#442042)
  * Fix ksystemstatstest failure
  * Initialize some more pointer members to nullptr
* Tue Jan  4 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.5
- No code changes since 5.23.4
* Tue Nov 30 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.4
- Changes since 5.23.3:
  * Don't update disks if no one is listening (kde#445039)
* Tue Nov  9 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.3
- No code changes since 5.23.2
* Tue Oct 26 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.2
- No code changes since 5.23.1
* Tue Oct 19 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.1
- No code changes since 5.23.0
* Fri Oct  8 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.0
- Changes since 5.22.90:
  * Fix ksystemstatstest failure
  * Add description for the Sensors package
  * Move find_package line
  * Fix missing "Hardware Sensors" on Linux (kde#442528)
  * Read extra amd gpu sensors
  * Correct discoverSensors chip detection (kde#442042)
  * Initialize some more pointer members to nullptr
- Drop patches, now upstream:
  * 0001-Initialize-some-more-pointer-members-to-nullptr.patch
  * 0001-Fix-ksystemstatstest-failure.patch
- Add new key + signature to plasma.keyring
* Thu Sep 16 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.90
- Changes since 5.22.5:
  * [plugins/gpu] Initialise properties (kde#442023)
  * Discover more hardware gpu sensors (kde#438318)
  * Use sensors to read amd gpu  temperature
  * Use SensorFeatureSensor in CPU plugin
  * Use SensorsFeatureSensor from libksysguard
  * Make libsensors required on Linux
  * Do not dereference iterator that has been invalidated
  * Only add a new VolumeObject if there's no other one with the same mounting point (kde#440477)
  * Add maximum for total GPU usage (kde#441148)
  * viewer: expand README with usage examples
  * viewer: drop the "rolling" display, expand diagnostics
  * daemon: log successfully loaded plugins, too
  * freebsd-cpu: fix CPU load data retrieval
  * freebsd-cpu: fix sysctl name of temperature sensor
  * Explicitly set KDE_COMPILERSETTINGS_LEVEL
  * Fix handling of IPV6 addresses (kde#436296)
  * gpu: Only scan pci devices
  * Add load averages sensors
  * Don't crash if there's no input subfeature (kde#439615)
  * Only add "All GPUs" sensors when there is at least one GPU with statistics (kde#436770)
  * Use 500ms update rate for network traffic sensors in NetworkManager backend
  * Filter duplicate provider names
  * Simplify plugin loading
  * Use version-less qt DBus macros
  * Init lib sensors centrally in the daemon (kde#437523)
  * Update .gitignore
- Add patch to fix autotest failure:
  * 0001-Fix-ksystemstatstest-failure.patch
- Add patch to fix crash on startup:
  * 0001-Initialize-some-more-pointer-members-to-nullptr.patch
* Tue Aug 31 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.5
- Changes since 5.22.4:
  * Fix handling of IPV6 addresses (kde#436296)
* Tue Jul 27 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.4
- Changes since 5.22.3:
  * gpu: Only scan pci devices
  * Don't crash if there's no input subfeature (kde#439615)
* Tue Jul  6 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.3
- Changes since 5.22.2.1:
  * Really fix build
  * Fix build
- Drop patches, now upstream:
  * 0001-Fix-build.patch
  * 0002-Really-fix-build.patch
* Sat Jun 26 2021 Fabian Vogt <fabian@ritter-vogt.de>
- s390 has no libsensors
- Add patches to fix build without libsensors:
  * 0001-Fix-build.patch
  * 0002-Really-fix-build.patch
* Wed Jun 23 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.2.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.2
- No code changes since 5.22.1
* Tue Jun 15 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.1
- No code changes since 5.22.0
* Thu Jun  3 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.0
- Changes since 5.21.90:
  * Only add "All GPUs" sensors when there is at least one GPU with statistics (kde#436770)
  * Use 500ms update rate for network traffic sensors in NetworkManager backend
  * Init lib sensors centrally in the daemon (kde#437523)
* Tue May 18 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Use GPL-2.0-or-later as substitute for LicenseRef-KDE-Accepted-GPL
* Thu May 13 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.90
  * New in Plasma 5.21.90
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.90
* Tue Apr 20 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Initial commit, split from ksysguard5
